@@ -1,5 +1,6 @@
 package Synapse::Monitor::Listener::Action;
 use base qw /Synapse::CLI::Config::Object/;
+use Synapse::Logger;
 use YAML::XS;
 use File::Spec;
 use Time::HiRes;
@@ -12,6 +13,7 @@ sub process {
     my $event = shift;
     my $tmp   = File::Spec->tmpdir() . '/' . Time::HiRes::time() . '.tmp.yml';
     my $exec  = $self->label();
+    logger ("exec YAML_FILE=$tmp $exec");
     system_execute ("YAML_FILE=$tmp $exec");
     unlink $tmp;
 }
